pub struct Config {
pub max_len_json_jwt_header: usize,
pub max_len_json_jwt_payload: usize,
pub max_len_jwt_signature: usize,
pub max_len_jwt_sub: usize,
pub max_len_jwt_aud: usize,
pub max_len_jwt_iss: usize,
pub max_len_salt: usize,
pub max_len_nonce_r: usize,
pub max_len_t_max: usize,
}Expand description
The configuration of the ZKLogin circuit.
Picking the numbers are a tradeoff. Picking a large number will require a larger circuit and thus more proving time. Picking a small number may make some statements unprovable.
Fields
max_len_json_jwt_header: usizeMaximum length in wires of the base64 decoded JWT header. Must be a multiple of 8.
max_len_json_jwt_payload: usizeMaximum length in wires of the base64 decoded JWT payload. Must be a multiple of 8.
max_len_jwt_signature: usizeMaximum length in wires of the base64 decoded JWT signature. Must be a multiple of 8.
max_len_jwt_sub: usizemax_len_jwt_aud: usizemax_len_jwt_iss: usizemax_len_salt: usizemax_len_nonce_r: usizemax_len_t_max: usizeImplementations
Sourceimpl Config
impl Config
pub const fn max_len_base64_jwt_header(&self) -> usize
pub const fn max_len_base64_jwt_payload(&self) -> usize
pub const fn max_len_base64_jwt_signature(&self) -> usize